library("stringr")
#'    This program implements Sun and Gilbert (2012, Scand J Statistics) and
#'    Gilbert and Sun (2014, Journal of the Royal Statistical Society Series C), to analyze
#'    an input data-set.
#'
#'     These papers provide estimation and testing methods for the mark-specific proportional hazards
#'    model accommodating that some failures have a missing mark, and allowing separate
#'    baseline mark-specific hazard functions for different baseline subgroups.
#'    Missing marks are handled via inverse-probability weighting (IPW) or augmented IPW.
#' 
#' @section input:
#' 
#' The input data file contains eight space-separated columns of data
#' \enumerate{ 
#' \item subject identifier 1  (could be arbitrary integers)
#'
#' \item subject identifier 2  (could be arbitrary integers)
#'
#' \item gender (1 or 0; the auxiliary covariate for predicting V)
#'
#' \item treatment (1 or 0 for vaccine or placebo)
#'
#' \item infection status (1 or 0 for infected or right-censored)
#'
#' \item time  (minimum of failure time or right-censoring time)
#'
#' \item R [indicator of observing the mark (1=infected and observed, 
#'         0=infected and unobserved, 2=uninfected)]
#'
#' \item mark V (8888 = infected and missing; 99 = uninfected and 
#'                   thus obviously missing) 
#' }
#' @section output:
#'
#' The program outputs 4 files with suffixes
#' '_VE'	'_Power'	'_Plot1'	'_Plot2'
#' The _VE file contains the etimated VE(v) curve with estimated
#' standard deviations for the IPW and AIPW methods
#'
#' The _Power file contains the results on the 8 testing 
#' procedures for testing \eqn{H_{10}} and \eqn{H_{20}}
#'
#' The _Plot1 file contains the outputted information needed
#' to plot the test process relevant for assessing departures 
#' from H_{10}
#'
#' The _Plot2 file contains the outputted information needed
#' to plot the test process relevant for assessing departures 
#' from H_{20}
#'
#' @section notes:
#' For the RV144 example, these files are read into the R code
#' cmprskPHContinMark_Makeplots in order to create plots 
#' displaying the results.
#'  ##############################################################
#'
#' The R function is a thin wrapper around the Fortran program 
#' 
#' @param inputf Input file name
#' @param outpre Prefix of output file names
#' @param nboot Number of bootstrap iterations, max 500
#' @param missmark 1 or 0, include cases with missing marks?
#' @param nauxiliary 1 or 0, include auxiliary information?
#' @param tau is the end of the follow-up period for conducting the analysis
#' @param tband h_1 in Gilbert and Sun (2014, Figure 3 caption)
#' @param hband h_2 = h in Gilbert and Sun (2014, Figure 3 caption)
#' @param a0 a in Gilbert and Sun (2014, Figure 3 caption) 
#' @param b1 b in Gilbert and Sun (2014, Figure 3 caption)
#' @param ntgrid number of time gridpoints 
#' @param nvgrid number of gridpoints for \eqn{\beta(v)}
#' @export
cmprskPHContinMark <-
    function(
       inputf=paste(system.file(package="cmprskPHContinMark"),"/extdata/practicedataRV144.dat",sep=""),
       outpre=basename(inputf),
       nboot=500,
       missmark=1,
       nauxiliary=1,
       tau=3.5,
       tband=0.5,
       hband=0.3,
       a0=0.05,
       b1=1.0,
       ntgrid=100,
       nvgrid=100 
    )
    { invisible (
       .Fortran("cmprskphcontinmark",
                str_pad(inputf,255,"right"),
                str_pad(outpre,255,"right"),
                as.integer(nboot),
                as.integer(missmark),
                as.integer(nauxiliary),
                as.single(tau),
                as.single(tband),
                as.single(hband),
                as.single(a0),
                as.single(b1),
                as.integer(ntgrid),
                as.integer(nvgrid)
                )
       )
    }
